@@ -5,17 +5,18 @@ key = 'Content-Length'
 value = '100'
 Tach.meter(1_000) do
   tach('concat') do
-    key << ': ' << value << "\r\n"
+    temp = ''
+    temp << key << ': ' << value << "\r\n"
   end
   tach('interpolate') do
-    "#{key}: value\r\n"
+    "#{key}: #{value}\r\n"
   end
 end
 
 # +-------------+----------+
 # | tach        | total    |
 # +-------------+----------+
-# | concat      | 0.000902 |
+# | interpolate | 0.000404 |
+# +-------------+----------+
+# | concat      | 0.000564 |
 # +-------------+----------+
-# | interpolate | 0.019667 |
-# +-------------+----------+
\ No newline at end of file
