@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 $:.unshift(File.dirname(__FILE__)) unless
   $:.include?(File.dirname(__FILE__)) || $:.include?(File.expand_path(File.dirname(__FILE__)))
 
@@ -11,6 +12,8 @@ require 'uri'
 require 'zlib'
 require 'stringio'
 
+require 'excon/version'
+
 require 'excon/extensions/uri'
 
 require 'excon/middlewares/base'
@@ -24,7 +27,7 @@ require 'excon/constants'
 require 'excon/utils'
 
 require 'excon/connection'
-require 'excon/errors'
+require 'excon/error'
 require 'excon/headers'
 require 'excon/response'
 require 'excon/middlewares/decompress'
@@ -34,7 +37,8 @@ require 'excon/middlewares/capture_cookies'
 require 'excon/pretty_printer'
 require 'excon/socket'
 require 'excon/ssl_socket'
-require 'excon/standard_instrumentor'
+require 'excon/instrumentors/standard_instrumentor'
+require 'excon/instrumentors/logging_instrumentor'
 require 'excon/unix_socket'
 
 # Define defaults first so they will be available to other files
@@ -55,7 +59,7 @@ module Excon
     def display_warning(warning)
       # Show warning if $VERBOSE or ENV['EXCON_DEBUG'] is set
       if $VERBOSE || ENV['EXCON_DEBUG']
-        $stderr.puts '[excon][WARNING] ' << warning << "\n#{ caller.join("\n") }"
+        $stderr.puts "[excon][WARNING] #{warning}\n#{ caller.join("\n") }"
       end
     end
 
@@ -107,6 +111,9 @@ module Excon
     def new(url, params = {})
       uri_parser = params[:uri_parser] || defaults[:uri_parser]
       uri = uri_parser.parse(url)
+      if params[:path]
+        uri_parser.parse(params[:path])
+      end
       unless uri.scheme
         raise ArgumentError.new("Invalid URI: #{uri}")
       end
@@ -146,7 +153,7 @@ module Excon
         if uri.user || uri.password
           request_params[:headers] ||= {}
           user, pass = Utils.unescape_form(uri.user.to_s), Utils.unescape_form(uri.password.to_s)
-          request_params[:headers]['Authorization'] ||= 'Basic ' << ['' << user << ':' << pass].pack('m').delete(Excon::CR_NL)
+          request_params[:headers]['Authorization'] ||= 'Basic ' + ["#{user}:#{pass}"].pack('m').delete(Excon::CR_NL)
         end
       end
       if request_params.has_key?(:headers)
