@@ -32,6 +32,16 @@ module Excon
       @data[:proxy] = new_proxy
     end
 
+    def logger
+      if @data[:instrumentor] && @data[:instrumentor].respond_to?(:logger)
+        @data[:instrumentor].logger
+      end
+    end
+    def logger=(logger)
+      Excon::LoggingInstrumentor.logger = logger
+      @data[:instrumentor] = Excon::LoggingInstrumentor
+    end
+
     # Initializes a new Connection instance
     #   @param [Hash<Symbol, >] params One or more optional params
     #     @option params [String] :body Default text to be sent over a socket. Only used if :body absent in Connection#request params
@@ -46,6 +56,7 @@ module Excon
     #     @option params [String] :ciphers Only use the specified SSL/TLS cipher suites; use OpenSSL cipher spec format e.g. 'HIGH:!aNULL:!3DES' or 'AES256-SHA:DES-CBC3-SHA'
     #     @option params [String] :proxy Proxy server; e.g. 'http://myproxy.com:8888'
     #     @option params [Fixnum] :retry_limit Set how many times we'll retry a failed request.  (Default 4)
+    #     @option params [Fixnum] :retry_interval Set how long to wait between retries. (Default 0)
     #     @option params [Class] :instrumentor Responds to #instrument as in ActiveSupport::Notifications
     #     @option params [String] :instrumentor_name Name prefix for #instrument events.  Defaults to 'excon'
     def initialize(params = {})
@@ -192,7 +203,7 @@ module Excon
 
     def response_call(datum)
       # ensure response_block is yielded to and body is empty from middlewares
-      if datum.has_key?(:response_block) && !datum[:response][:body].empty?
+      if datum.has_key?(:response_block) && !(datum[:response][:body].nil? || datum[:response][:body].empty?)
         response_body = datum[:response][:body].dup
         datum[:response][:body] = ''
         content_length = remaining = response_body.bytesize
@@ -218,12 +229,12 @@ module Excon
       datum[:headers] = @data[:headers].merge(datum[:headers] || {})
 
       if datum[:user] || datum[:password]
-        user, pass = Utils.unescape_form(datum[:user].to_s), Utils.unescape_form(datum[:password].to_s)
+        user, pass = Utils.unescape_uri(datum[:user].to_s), Utils.unescape_uri(datum[:password].to_s)
         datum[:headers]['Authorization'] ||= 'Basic ' + ["#{user}:#{pass}"].pack('m').delete(Excon::CR_NL)
       end
 
       if datum[:scheme] == UNIX
-        datum[:headers]['Host']   = ''
+        datum[:headers]['Host']   ||= ''
       else
         datum[:headers]['Host']   ||= datum[:host] + port_string(datum)
       end
@@ -300,6 +311,21 @@ module Excon
       responses
     end
 
+    # Sends the supplied requests to the destination host using pipelining in
+    # batches of @limit [Numeric] requests. This is your soft file descriptor
+    # limit by default, typically 256.
+    #   @pipeline_params [Array<Hash>] pipeline_params An array of one or more optional params, override defaults set in Connection.new, see #request for details
+    def batch_requests(pipeline_params, limit = nil)
+      limit ||= Process.respond_to?(:getrlimit) ? Process.getrlimit(:NOFILE).first : 256
+      responses = []
+
+      pipeline_params.each_slice(limit) do |params|
+        responses.concat(requests(params))
+      end
+
+      responses
+    end
+
     def reset
       if old_socket = sockets.delete(@socket_key)
         old_socket.close rescue nil
@@ -407,10 +433,16 @@ module Excon
     end
 
     def sockets
+      @_excon_sockets ||= {}
+
       if @data[:thread_safe_sockets]
-        Thread.current[:_excon_sockets] ||= {}
+        # In a multi-threaded world, if the same connection is used by multiple
+        # threads at the same time to connect to the same destination, they may
+        # stomp on each other's sockets.  This ensures every thread gets their
+        # own socket cache, within the context of a single connection.
+        @_excon_sockets[Thread.current.object_id] ||= {}
       else
-        @_excon_sockets ||= {}
+        @_excon_sockets
       end
     end
 
@@ -473,11 +505,11 @@ module Excon
             end
           else
             unless uri.host && uri.port && uri.scheme
-              raise Excon::Errors::ProxyParseError, "Proxy is invalid"
+              raise Excon::Errors::ProxyParse, "Proxy is invalid"
             end
           end
         else
-          raise Excon::Errors::ProxyParseError, "Proxy is invalid"
+          raise Excon::Errors::ProxyParse, "Proxy is invalid"
         end
 
         if @data.has_key?(:proxy) && @data[:scheme] == 'http'
