@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 module Excon
 
-  VERSION = '0.54.0'
-
   CR_NL = "\r\n"
 
   DEFAULT_CA_FILE = File.expand_path(File.join(File.dirname(__FILE__), "..", "..", "data", "cacert.pem"))
@@ -57,6 +55,7 @@ module Excon
     :response_block,
     :retries_remaining, # used internally
     :retry_limit,
+    :retry_interval,
     :versions,
     :write_timeout
   ]
@@ -64,8 +63,10 @@ module Excon
   VALID_CONNECTION_KEYS = VALID_REQUEST_KEYS + [
     :ciphers,
     :client_key,
+    :client_key_data,
     :client_key_pass,
     :client_cert,
+    :client_cert_data,
     :certificate,
     :certificate_path,
     :disable_proxy,
