@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Excon
   module Middleware
     class Idempotent < Excon::Middleware::Base
@@ -11,6 +12,9 @@ module Excon
               datum[:idempotent] = false
             end
           end
+          if datum.has_key?(:response_block) && datum[:response_block].respond_to?(:rewind)
+            datum[:response_block].rewind
+          end
           if datum.has_key?(:pipeline)
             Excon.display_warning("Excon requests can not be :idempotent when pipelining.")
             datum[:idempotent] = false
@@ -19,6 +23,9 @@ module Excon
 
         if datum[:idempotent] && [Excon::Errors::Timeout, Excon::Errors::SocketError,
             Excon::Errors::HTTPStatusError].any? {|ex| datum[:error].kind_of?(ex) } && datum[:retries_remaining] > 1
+
+          sleep(datum[:retry_interval]) if datum[:retry_interval]
+
           # reduces remaining retries, reset connection, and restart request_call
           datum[:retries_remaining] -= 1
           connection = datum.delete(:connection)
