@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Excon
   class Socket
     include Utils
@@ -23,7 +24,7 @@ module Excon
     def initialize(data = {})
       @data = data
       @nonblock = data[:nonblock]
-      @read_buffer = ''
+      @read_buffer = String.new
       @eof = false
       connect
     end
@@ -40,23 +41,15 @@ module Excon
 
     def readline
       return legacy_readline if RUBY_VERSION.to_f <= 1.8_7
-      buffer = ''
+      buffer = String.new
       begin
         buffer << @socket.read_nonblock(1) while buffer[-1] != "\n"
         buffer
-      rescue Errno::EAGAIN, Errno::EWOULDBLOCK, IO::WaitReadable 
-        if timeout_reached('read')
-          raise_timeout_error('read')
-        else
-          retry
-        end
-      rescue OpenSSL::SSL::SSLError => e
-        if e.message == 'read would block'
-          if timeout_reached('read')
-            raise_timeout_error('read')
-          else
-            retry
-          end
+      rescue Errno::EAGAIN, Errno::EWOULDBLOCK, IO::WaitReadable
+        select_with_timeout(@socket, :read) && retry
+      rescue OpenSSL::SSL::SSLError => error
+        if error.message == 'read would block'
+          select_with_timeout(@socket, :read) && retry
         else
           raise(error)
         end
@@ -64,12 +57,12 @@ module Excon
     end
 
     def legacy_readline
-       begin
+      begin
         Timeout.timeout(@data[:read_timeout]) do
           @socket.readline
-      end
+        end
       rescue Timeout::Error
-      raise Excon::Errors::Timeout.new('read timeout reached')
+        raise Excon::Errors::Timeout.new('read timeout reached')
       end
     end
 
@@ -108,12 +101,12 @@ module Excon
       addrinfo = ::Socket.getaddrinfo(*args)
 
       addrinfo.each do |_, port, _, ip, a_family, s_type|
-        @remote_ip = ip
-
         # already succeeded on previous addrinfo
         if @socket
           break
         end
+        
+        @remote_ip = ip
 
         # nonblocking connect
         begin
@@ -135,9 +128,7 @@ module Excon
           end
           @socket = socket
         rescue Errno::EINPROGRESS
-          unless IO.select(nil, [socket], nil, @data[:connect_timeout])
-            raise(Excon::Errors::Timeout.new('connect timeout reached'))
-          end
+          select_with_timeout(socket, :connect_write)
           begin
             socket.connect_nonblock(sockaddr)
             @socket = socket
@@ -163,37 +154,29 @@ module Excon
 
     def read_nonblock(max_length)
       begin
-            if max_length
-              until @read_buffer.length >= max_length
-                @read_buffer << @socket.read_nonblock(max_length - @read_buffer.length)
-              end
-            else
-              loop do
-                @read_buffer << @socket.read_nonblock(@data[:chunk_size])
-              end
-            end
-          rescue OpenSSL::SSL::SSLError => error
-            if error.message == 'read would block'
-              if timeout_reached('read')  
-                raise_timeout_error('read') 
-              else 
-                retry
-              end
-            else
-              raise(error)
-            end
-          rescue Errno::EAGAIN, Errno::EWOULDBLOCK, IO::WaitReadable
-            if @read_buffer.empty?
-              # if we didn't read anything, try again...
-              if timeout_reached('read') 
-                raise_timeout_error('read') 
-              else
-                retry
-              end
-            end
-          rescue EOFError
-            @eof = true
+        if max_length
+          until @read_buffer.length >= max_length
+            @read_buffer << @socket.read_nonblock(max_length - @read_buffer.length)
           end
+        else
+          loop do
+            @read_buffer << @socket.read_nonblock(@data[:chunk_size])
+          end
+        end
+      rescue OpenSSL::SSL::SSLError => error
+        if error.message == 'read would block'
+          select_with_timeout(@socket, :read) && retry
+        else
+          raise(error)
+        end
+      rescue Errno::EAGAIN, Errno::EWOULDBLOCK, IO::WaitReadable
+        if @read_buffer.empty?
+          # if we didn't read anything, try again...
+          select_with_timeout(@socket, :read) && retry
+        end
+      rescue EOFError
+        @eof = true
+      end
 
       if max_length
         if @read_buffer.empty?
@@ -211,21 +194,13 @@ module Excon
       @socket.read(max_length)
     rescue OpenSSL::SSL::SSLError => error
       if error.message == 'read would block'
-        if timeout_reached('read') 
-          raise_timeout_error('read') 
-        else
-          retry
-        end
+        select_with_timeout(@socket, :read) && retry
       else
         raise(error)
       end
     rescue Errno::EAGAIN, Errno::EWOULDBLOCK, IO::WaitReadable
       if @read_buffer.empty?
-        if timeout_reached('read') 
-          raise_timeout_error('read') 
-        else
-          retry
-        end
+        select_with_timeout(@socket, :read) && retry
       end
     rescue EOFError
       @eof = true
@@ -234,15 +209,15 @@ module Excon
     def write_nonblock(data)
       if FORCE_ENC
         data.force_encoding('BINARY')
-          end
+      end
       loop do
         written = nil
         begin
           # I wish that this API accepted a start position, then we wouldn't
           # have to slice data when there is a short write.
           written = @socket.write_nonblock(data)
-        rescue Errno::EFAULT
-          if OpenSSL::OPENSSL_LIBRARY_VERSION.split(' ')[1] == '1.0.2'
+        rescue Errno::EFAULT => error
+          if OpenSSL.const_defined?(:OPENSSL_LIBRARY_VERSION) && OpenSSL::OPENSSL_LIBRARY_VERSION.split(' ')[1] == '1.0.2'
             msg = "The version of OpenSSL this ruby is built against (1.0.2) has a vulnerability
                    which causes a fault. For more, see https://github.com/excon/excon/issues/467"
             raise SecurityError.new(msg)
@@ -253,11 +228,7 @@ module Excon
           if error.is_a?(OpenSSL::SSL::SSLError) && error.message != 'write would block'
             raise error
           else
-            if timeout_reached('write') 
-              raise_timeout_error('write') 
-            else 
-              retry
-            end
+            select_with_timeout(@socket, :write) && retry
           end
         end
 
@@ -278,25 +249,22 @@ module Excon
       if error.is_a?(OpenSSL::SSL::SSLError) && error.message != 'write would block'
         raise error
       else
-        if timeout_reached('write') 
-          raise_timeout_error('write') 
-        else
-          retry
-        end
+        select_with_timeout(@socket, :write) && retry
       end
     end
 
-    def timeout_reached(type)
-      if type == 'read'
-        args = [[@socket], nil, nil, @data[:read_timeout]]
-      else
-        args = [nil, [@socket], nil, @data[:write_timeout]]
+    def select_with_timeout(socket, type)
+      select = case type
+      when :connect_read
+        IO.select([socket], nil, nil, @data[:connect_timeout])
+      when :connect_write
+        IO.select(nil, [socket], nil, @data[:connect_timeout])
+      when :read
+        IO.select([socket], nil, nil, @data[:read_timeout])
+      when :write
+        IO.select(nil, [socket], nil, @data[:write_timeout])
       end
-      IO.select(*args) ? nil : true
-    end
-
-    def raise_timeout_error(type)
-      fail Excon::Errors::Timeout.new("#{type} timeout reached")
+      select || raise(Excon::Errors::Timeout.new("#{type} timeout reached"))
     end
 
     def unpacked_sockaddr
