@@ -1,4 +1,5 @@
 require 'sinatra'
+require 'json'
 require File.join(File.dirname(__FILE__), 'webrick_patch')
 
 class Basic < Sinatra::Base
@@ -10,6 +11,11 @@ class Basic < Sinatra::Base
     'x' * value.to_i
   end
 
+  get('/headers') do
+    content_type :json
+    request.env.select{|key, _| key.start_with? 'HTTP_'}.to_json
+  end
+
   post('/body-sink') do
     request.body.read.size.to_s
   end
@@ -22,6 +28,10 @@ class Basic < Sinatra::Base
     echo
   end
 
+  get('/echo dirty') do
+    echo
+  end
+
   private
 
   def echo
